"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.UpdateCheckerNotifier = void 0;
const electron_1 = require("electron");
const axios_1 = __importDefault(require("axios"));
const events_1 = require("events");
const github_url_to_object_1 = __importDefault(require("github-url-to-object"));
const path = __importStar(require("path"));
const semver_1 = require("semver");
const languages_1 = require("./languages");
let format = require('@stdlib/string-format');
class UpdateCheckerNotifier extends events_1.EventEmitter {
    /**
     * The current application version.
     */
    currentVersion;
    /**
     * Optional, use repository field from your package.json when not specified
     * `user/repo`
     */
    repository;
    /**
     * Optional, GitHub api access token
     */
    token;
    /**
     * Optional, default `false`, allows to check for updates during development as well
     * @default false
     */
    debug = false;
    /**
    * Optional, notify pre-release version
    * @default false
    */
    enablePreRelease = false;
    /**
     * Optional, notify when new version available, otherwise remain silent
     * @default true
     */
    enableNewVersionAvailableDialog = true;
    /**
     * Optional, notifies you when you are already running the latest version.
     * @default false
     */
    enableLatestVersionDialog = false;
    /**
     * Optional, notifies you when an error occurs
     * @default false
     */
    enableErrorDialog = false;
    /**
     * Optional, default Language.EN
     * @default Language.EN
     */
    get language() {
        return this._language;
    }
    set language(value) {
        this._language = value;
    }
    _language = "en" /* Language.EN */;
    /**
     * The logger. You can pass [electron-log](https://github.com/megahertz/electron-log), [winston](https://github.com/winstonjs/winston) or another logger with the following interface: `{ info(), warn(), error() }`.
     * Set it to `null` if you would like to disable a logging feature.
     */
    get logger() {
        return this._logger;
    }
    set logger(value) {
        this._logger = value == null ? new NoOpLogger() : value;
    }
    _logger = console;
    translation;
    constructor() {
        super();
        this.loadTranslation();
        const currentVersionString = electron_1.app.getVersion();
        const currentVersion = (0, semver_1.parse)(currentVersionString);
        if (currentVersion == null) {
            throw Error(format(this.translation.error.currentVersionInvalid, currentVersionString));
        }
        this.currentVersion = currentVersion;
    }
    updateNotification(options) {
        this.loadOptions(options);
        this.loadTranslation();
        if (electron_1.app.isReady()) {
            this.checkForUpdates();
        }
        else {
            electron_1.app.on('ready', () => {
                this.checkForUpdates();
            });
        }
    }
    loadOptions(options) {
        if (!options)
            return;
        if (options.repository)
            this.repository = options.repository;
        if (options.token)
            this.token = options.token;
        if (options.debug)
            this.debug = options.debug;
        if (options.enablePreRelease)
            this.enablePreRelease = options.enablePreRelease;
        if (options.enableNewVersionAvailableDialog)
            this.enableNewVersionAvailableDialog = options.enableNewVersionAvailableDialog;
        if (options.enableErrorDialog)
            this.enableErrorDialog = options.enableErrorDialog;
        if (options.enableLatestVersionDialog)
            this.enableLatestVersionDialog = options.enableLatestVersionDialog;
        if (options.language)
            this.language = options.language;
        if (options.logger)
            this.logger = options.logger;
    }
    async checkForUpdates() {
        if (!electron_1.app.isPackaged && !this.debug) {
            this._logger.info(this.translation.warn.skipCheckForUpdates);
            return;
        }
        if (!this.repository) {
            const pkg = require(path.join(electron_1.app.getAppPath(), 'package.json'));
            const ghObj = (0, github_url_to_object_1.default)(pkg.repository);
            if (!ghObj) {
                let error = new Error(this.translation.error.urlNotFound);
                this.error(error);
                this._logger.error(this.translation.error.urlNotFound);
                throw error;
            }
            this.repository = ghObj.user + '/' + ghObj.repo;
        }
        let latestRelease = null;
        try {
            this.emit("checking-for-update");
            this._logger.info(this.translation.info.checkingForUpdate);
            const { data: releases } = await axios_1.default.get(`https://api.github.com/repos/${this.repository}/releases`, {
                headers: this.token ? { authorization: `token ${this.token}` } : {},
            });
            latestRelease = releases[0];
        }
        catch (error) {
            this.error(error);
            this._logger.error(this.translation.error.checkingUpdate);
            if (this.enableErrorDialog) {
                this.showDialog(this.translation.error.checkingUpdate, 'error');
            }
        }
        if (!latestRelease)
            return;
        const latestVersion = (0, semver_1.parse)(latestRelease.tag_name);
        if (latestVersion == null) {
            let error = Error(format(this.translation.error.lastVersionInvalid, latestRelease.tag_name));
            this.error(error);
            throw error;
        }
        if (latestRelease.prerelease && !this.enablePreRelease) {
            this._logger.info(this.translation.info.skippingPreRelease);
            return;
        }
        const updateInfo = { version: latestVersion.version, currentVersion: this.currentVersion.version, descriptionRelease: latestRelease.body, preRelease: latestRelease.prerelease };
        if ((0, semver_1.gt)(latestVersion, this.currentVersion)) {
            this.emit("update-available", updateInfo);
            this._logger.info(format(this.translation.info.newVersionAvailableMessage, latestVersion.version));
            if (this.enableNewVersionAvailableDialog) {
                this.showUpdateDialog(latestRelease);
            }
        }
        else if ((0, semver_1.gte)(this.currentVersion, latestVersion)) {
            this.emit("this-is-last-update", updateInfo);
            this._logger.info(this.translation.info.runningLastVersion);
            if (this.enableLatestVersionDialog) {
                this.showDialog(this.translation.info.runningLastVersion);
            }
        }
        else {
            this.emit("update-not-available", updateInfo);
            this._logger.info(this.translation.warn.updateNotAvailable);
        }
    }
    showUpdateDialog(release) {
        let detail = this.translation.dialogNewVersionAvailableDetail.trim();
        electron_1.dialog.showMessageBox({
            title: electron_1.app.getName(),
            type: 'info',
            message: this.translation.dialogNewVersionAvailableMessage,
            detail: format(detail, electron_1.app.getVersion(), release.tag_name),
            buttons: [this.translation.download, this.translation.later],
            defaultId: 0,
            cancelId: 1,
        }).then(({ response }) => {
            if (response === 0) {
                setImmediate(() => {
                    electron_1.shell.openExternal(release.html_url);
                });
            }
        }).catch((error) => {
            this._logger.error(error);
            throw new Error(error);
        });
    }
    showDialog = (detail, type = 'info') => {
        electron_1.dialog.showMessageBox({
            title: electron_1.app.getName(),
            message: this.translation.updateChecker,
            buttons: [this.translation.close],
            defaultId: 0,
            cancelId: 0,
            type,
            detail,
        });
    };
    error(error) {
        this.emit('error', error);
        this._logger.error(error);
    }
    loadTranslation() {
        const translation = languages_1.Languages[this._language];
        this.translation = translation ? translation : languages_1.Languages["en" /* Language.EN */];
    }
    ;
}
exports.UpdateCheckerNotifier = UpdateCheckerNotifier;
/** @private */
class NoOpLogger {
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    info(message) {
        // ignore
    }
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    warn(message) {
        // ignore
    }
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    error(message) {
        // ignore
    }
}
